"""Tests for authorization tools."""

import datetime
from zoneinfo import ZoneInfo

import pytest
import vws_auth_tools
from freezegun import freeze_time


def test_rfc_1123_date() -> None:
    """The date is returned in the format described in the VWS documentation.

    See https://developer.vuforia.com/library/web-api/vuforia-web-api-authentication:

    ```
    Date: This is the current date per RFC 2616, section 3.3.1, rfc1123-date
    format, for example, Sun, 22 Apr 2012 08:49:37 GMT,

    NOTE: The date and time always refer to GMT.
    ```
    """
    not_gmt_timezone = ZoneInfo("America/New_York")
    frozen_time = datetime.datetime(
        year=2015,
        month=2,
        day=5,
        hour=9,
        minute=55,
        second=12,
        microsecond=11,
        tzinfo=not_gmt_timezone,
    )
    with freeze_time(frozen_time):
        result = vws_auth_tools.rfc_1123_date()

    assert result == "Thu, 05 Feb 2015 14:55:12 GMT"


@pytest.mark.parametrize("content", [b"some_bytes", "some_bytes"])
def test_authorization_header(content: bytes | str) -> None:
    """The Authorization header is constructed as documented.

    This example has been run on known-working code and so any refactor should
    continue to pass this test.
    """
    access_key = "my_access_key"
    # Ignore "Possible hardcoded password" as it is appropriate here.
    secret_key = "my_secret_key"  # noqa: S105
    method = "HTTPMETHOD"
    content_type = "some/content/type"
    date = "some_date_string"
    request_path = "/foo"

    result = vws_auth_tools.authorization_header(
        access_key=access_key,
        secret_key=secret_key,
        method=method,
        content=content,
        content_type=content_type,
        date=date,
        request_path=request_path,
    )

    assert result == "VWS my_access_key:8Uy6SKuO5sSBY2X8/znlPFmDF/k="


@pytest.mark.parametrize("content", [b"", None])
def test_authorization_header_none_content(content: bytes | None) -> None:
    """
    The Authorization header is the same whether the content is None or b"".
    """
    access_key = "my_access_key"
    # Ignore "Possible hardcoded password" as it is appropriate here.
    secret_key = "my_secret_key"  # noqa: S105
    method = "HTTPMETHOD"
    content_type = "some/content/type"
    date = "some_date_string"
    request_path = "/foo"

    result = vws_auth_tools.authorization_header(
        access_key=access_key,
        secret_key=secret_key,
        method=method,
        content=content,
        content_type=content_type,
        date=date,
        request_path=request_path,
    )

    assert result == "VWS my_access_key:XXvKyRyMkwS8/1P1WLQ0duqNpKs="



"""Setup for Sybil."""

from doctest import ELLIPSIS

from sybil import Sybil
from sybil.parsers.rest import (
    CaptureParser,
    DocTestParser,
    PythonCodeBlockParser,
)

sybil_obj = Sybil(
    parsers=[
        DocTestParser(optionflags=ELLIPSIS),
        PythonCodeBlockParser(),
        CaptureParser(),
    ],
    patterns=["*.rst", "*.py"],
)

pytest_collect_file = sybil_obj.pytest()



#!/usr/bin/env python3
"""Configuration for Sphinx."""

# pylint: disable=invalid-name

import datetime
import importlib.metadata

project = "VWS-Auth-Tools"
author = "Adam Dangoor"

extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.intersphinx",
    "sphinx.ext.napoleon",
    "sphinx-prompt",
    "sphinx_substitution_extensions",
    "sphinxcontrib.spelling",
]

templates_path = ["_templates"]
source_suffix = ".rst"
master_doc = "index"

year = datetime.datetime.now(tz=datetime.UTC).year
project_copyright = f"{year}, {author}"

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# Use ``importlib.metadata.version`` as per
# https://setuptools-scm.readthedocs.io/en/latest/usage/#usage-from-sphinx.
version = importlib.metadata.version(distribution_name=project)
_month, _day, _year, *_ = version.split(".")
release = f"{_month}.{_day}.{_year}"

language = "en"

# The name of the syntax highlighting style to use.
pygments_style = "sphinx"

# Output file base name for HTML help builder.
htmlhelp_basename = "VWSAUTHTOOLSdoc"
autoclass_content = "init"
intersphinx_mapping = {
    "python": ("https://docs.python.org/3.12", None),
}
nitpicky = True
warning_is_error = True

html_theme = "furo"
html_title = project
html_show_copyright = False
html_show_sphinx = False
html_show_sourcelink = False
html_theme_options = {
    "sidebar_hide_name": False,
}

# Retry link checking to avoid transient network errors.
linkcheck_retries = 5
linkcheck_ignore = [
    # Requires login.
    r"https://developer.vuforia.com/targetmanager",
]

spelling_word_list_filename = "../../spelling_private_dict.txt"

autodoc_member_order = "bysource"

rst_prolog = f"""
.. |project| replace:: {project}
.. |release| replace:: {release}
.. |github-owner| replace:: VWS-Python
.. |github-repository| replace:: vws-auth-tools
"""
